"use strict";
/// <reference types="@types/jest" />
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const path_1 = tslib_1.__importDefault(require("path"));
const _1 = require(".");
const terminal_emulator_1 = require("./terminal-emulator");
jest.mock('./terminal-emulator', () => ({
    __esModule: true,
    // default: 'mockedDefaultExport',
    terminalEmulator: jest.fn().mockImplementation(() => {
        return {
            write: () => {
                // tslint:disable-next-line
            },
        };
    }),
}));
beforeEach(() => {
    // Clear all instances and calls to constructor and all methods:
    // @ts-ignore
    terminal_emulator_1.terminalEmulator.mockClear();
});
describe('PluginCodeCoverage', () => {
    test('exists', () => {
        expect(typeof _1.PluginTerminal).toBe('function');
    });
    test('create instance', () => tslib_1.__awaiter(this, void 0, void 0, function* () {
        const inst = new _1.PluginTerminal({
            cmd: 'hello',
        });
        inst.connected();
        expect(inst.name).toBe('PluginTerminal');
        expect(inst.lowerCaseName).toBe('plugin-terminal');
        expect(typeof inst.clientConfig.cwd).toBe('string');
        expect(inst.clientConfig.cmd).toBe('hello');
        // @ts-ignore
        expect(inst._autostart).toBe(false);
        expect(Array.isArray(inst.clientFiles)).toBe(true);
    }));
    test('trigger connected without connect before', () => tslib_1.__awaiter(this, void 0, void 0, function* () {
        const inst = new _1.PluginTerminal({
            cmd: 'hello',
        });
        // @ts-ignore
        inst.on = undefined;
        inst.connected();
    }));
    test('cwd defined', () => tslib_1.__awaiter(this, void 0, void 0, function* () {
        const inst = new _1.PluginTerminal({
            cmd: 'hello',
            cwd: 'test',
        });
        expect(inst.clientConfig.cwd).toBe(path_1.default.join(process.cwd(), 'test'));
    }));
    test('autostart', () => tslib_1.__awaiter(this, void 0, void 0, function* () {
        const inst = new _1.PluginTerminal({
            cmd: 'hello',
            autostart: true,
        });
        expect(terminal_emulator_1.terminalEmulator).toHaveBeenCalledTimes(1);
    }));
    test('create', () => tslib_1.__awaiter(this, void 0, void 0, function* () {
        const inst = new _1.PluginTerminal({
            cmd: 'hello',
            autostart: true,
        });
        inst.create();
        expect(terminal_emulator_1.terminalEmulator).toHaveBeenCalledWith({
            // @ts-ignore
            cwd: inst._cwd,
            // @ts-ignore
            onData: inst.recieveData,
            // @ts-ignore
            onStopProcessing: inst.handleTermStopProcessing,
        });
        expect(terminal_emulator_1.terminalEmulator).toHaveBeenCalledTimes(2);
    }));
    test('handleConnected', () => tslib_1.__awaiter(this, void 0, void 0, function* () {
        const inst = new _1.PluginTerminal({
            cmd: 'hello',
        });
        // @ts-ignore
        const spy = jest.spyOn(inst, 'send');
        // @ts-ignore
        inst.handleConnected();
        expect(spy).toHaveBeenCalled();
        // @ts-ignore
        expect(spy).toHaveBeenCalledWith('connected', inst._terminalLog);
        spy.mockRestore();
    }));
    test('handleConnected _stopProcessingTriggered', () => tslib_1.__awaiter(this, void 0, void 0, function* () {
        const inst = new _1.PluginTerminal({
            cmd: 'hello',
        });
        // @ts-ignore
        inst._stopProcessingTriggered = true;
        // @ts-ignore
        const spy = jest.spyOn(inst, 'send');
        // @ts-ignore
        inst.handleConnected();
        expect(spy).toHaveBeenCalled();
        // @ts-ignore
        expect(spy).toHaveBeenNthCalledWith(1, 'connected', inst._terminalLog);
        expect(spy).toHaveBeenNthCalledWith(2, 'stopped');
        spy.mockRestore();
    }));
    test('handleTermStopProcessing', () => tslib_1.__awaiter(this, void 0, void 0, function* () {
        const inst = new _1.PluginTerminal({
            cmd: 'hello',
        });
        // @ts-ignore
        const spy = jest.spyOn(inst, 'send');
        // @ts-ignore
        inst.handleTermStopProcessing();
        // @ts-ignore
        expect(inst._stopProcessingTriggered).toBe(true);
        expect(spy).toHaveBeenCalled();
        expect(spy).toHaveBeenCalledWith('stopped');
        spy.mockRestore();
    }));
    test('recieveData store data and send them', () => tslib_1.__awaiter(this, void 0, void 0, function* () {
        const inst = new _1.PluginTerminal({
            cmd: 'hello',
        });
        // @ts-ignore
        const spy = jest.spyOn(inst, 'send');
        // @ts-ignore
        inst.recieveData('test');
        // @ts-ignore
        expect(inst._terminalLog).toBe('test');
        expect(spy).toHaveBeenCalledWith('recieve', 'test');
        spy.mockRestore();
    }));
    test('recieveData with unavailable send method should store but not send them', () => tslib_1.__awaiter(this, void 0, void 0, function* () {
        const inst = new _1.PluginTerminal({
            cmd: 'hello',
        });
        // @ts-ignore
        inst.send = undefined;
        // @ts-ignore
        inst.recieveData('test');
        // @ts-ignore
        expect(inst._terminalLog).toBe('test');
    }));
    test('stop should kill running term process and create a new term instance', (done) => {
        const inst = new _1.PluginTerminal({
            cmd: 'hello',
        });
        // @ts-ignore
        const spy = jest.spyOn(inst, 'create');
        // @ts-ignore
        inst._term = {
            kill() {
                done();
            },
        };
        // @ts-ignore
        inst.stop();
        expect(spy).toHaveBeenCalled();
        spy.mockRestore();
    });
    test('clean should write clean command and stored data', (done) => {
        const inst = new _1.PluginTerminal({
            cmd: 'hello',
        });
        // @ts-ignore
        inst._term = {
            write(command) {
                expect(command).toBe('\x1Bc');
                done();
            },
        };
        // @ts-ignore
        expect(inst._terminalLog).toBe('');
        // @ts-ignore
        inst.clean();
    });
});
//# sourceMappingURL=index.spec.js.map